cmoncrawl.processor.pipeline.streamer.StreamerFileJSON.stream
=============================================================

.. currentmodule:: cmoncrawl.processor.pipeline.streamer

.. automethod:: StreamerFileJSON.stream